# Simulate Calibration Data

```{warning}
Incomplete documentation.
```

The simulation pipeline allows to simulate calibration data for various components of the Cherenkov Telescope Array Observatory (CTAO) including the simulation of calibration devices.

## Calibration events

To generate calibration events, including pedestal, dark pedestal, and flasher events, use the `simtools-simulate-calibration-events` command.

- [simtools-simulate-flasher](simulate_flasher): Simulate flasher devices for camera calibration.

## Muons

## Illuminators

- [simtools-simulate-illuminator](simulate_illuminator): Simulate illuminators for telescope throughput calibration, including optics
and camera.
